==> ebt_tabs-1.0.0.tar.gz: ebt_tabs/src/Plugin/Field/FieldWidget/EbtSettingsTabsWidget.php <==
<?php

/**
 * @file
 * Contains \Drupal\ebt_tabs\Plugin\Field\FieldWidget\EbtSettingsTabsWidget.
 */

namespace Drupal\ebt_tabs\Plugin\Field\FieldWidget;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\WidgetBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Plugin implementation of the 'ebt_settings_tabs' widget.
 *
 * @FieldWidget(
 *   id = "ebt_settings_tabs",
 *   label = @Translation("EBT Tabs settings"),
 *   field_types = {
 *     "ebt_settings"
 *   }
 * )
 */
class EbtSettingsTabsWidget extends WidgetBase {

  /**
   * {@inheritdoc}
   */
  public function formElement(FieldItemListInterface $items, $delta, array $element, array &$form, FormStateInterface $form_state) {
    $element['ebt_settings'] = [
      '#type' => 'details',
      '#title' => 'Block settings',
      '#open' => FALSE,
    ];

    $element['ebt_settings']['styles'] = [
      '#title' => $this->t('Styles'),
      '#type' => 'radios',
      '#options' => [
        'default' => 'Default',
        'without_header_background' => 'Without header background',
        'minimalist_tabs' => 'Minimalist tabs',
        'tabs_like_buttons' => 'Tabs like buttons',
        'vertical_tabs' => 'Vertical tabs',
        'vertical_tabs_rotated' => 'Vertical tabs rotated',
      ],
      '#default_value' => isset($items[$delta]->ebt_settings['styles']) ? $items[$delta]->ebt_settings['styles'] : 'default',
      '#description' => $this->t('Controls the height of the accordion and each panel.'),
    ];


    $element['ebt_settings']['active'] = [
      '#title' => $this->t('Active section'),
      '#type' => 'textfield',
      '#default_value' => isset($items[$delta]->ebt_settings['active']) ? $items[$delta]->ebt_settings['active'] : NULL,
      '#description' => $this->t('The zero-based index of the panel that is active (open). A negative value selects panels going backward from the last panel.'),
    ];

    $element['ebt_settings']['collapsible'] = [
      '#title' => $this->t('Collapsible'),
      '#type' => 'checkbox',
      '#default_value' => isset($items[$delta]->ebt_settings['collapsible']) ? $items[$delta]->ebt_settings['collapsible'] : NULL,
      '#description' => 'Whether all the sections can be closed at once. Allows collapsing the active section.',
    ];

    $element['ebt_settings']['closed'] = [
      '#title' => $this->t('All closed'),
      '#type' => 'checkbox',
      '#default_value' => isset($items[$delta]->ebt_settings['closed']) ? $items[$delta]->ebt_settings['closed'] : NULL,
      '#description' => 'Collapses all panels',
    ];

    $element['ebt_settings']['disable'] = [
      '#title' => $this->t('Disable'),
      '#type' => 'checkbox',
      '#default_value' => isset($items[$delta]->ebt_settings['disable']) ? $items[$delta]->ebt_settings['disable'] : NULL,
      '#description' => $this->t('Disables the tabs.'),
    ];

    $element['ebt_settings']['heightStyle'] = [
      '#title' => $this->t('Height style'),
      '#type' => 'radios',
      '#options' => [
        'auto' => 'Auto',
        'fill' => 'Fill',
        'content' => 'Content',
      ],
      '#default_value' => isset($items[$delta]->ebt_settings['heightStyle']) ? $items[$delta]->ebt_settings['heightStyle'] : 'content',
      '#description' => $this->t('Controls the height of the tabs and each panel.'),
    ];

    return $element;
  }

  /**
   * {@inheritdoc}
   */
  public function massageFormValues(array $values, array $form, FormStateInterface $form_state) {
    foreach ($values as &$value) {
      $value += ['ebt_settings' => []];
    }
    return $values;
  }

}

==> ebt_tabs-1.0.2.tar.gz: ebt_tabs/src/Plugin/Field/FieldWidget/EbtSettingsTabsWidget.php <==
<?php

/**
 * @file
 * Contains \Drupal\ebt_tabs\Plugin\Field\FieldWidget\EbtSettingsTabsWidget.
 */

namespace Drupal\ebt_tabs\Plugin\Field\FieldWidget;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\WidgetBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Plugin implementation of the 'ebt_settings_tabs' widget.
 *
 * @FieldWidget(
 *   id = "ebt_settings_tabs",
 *   label = @Translation("EBT Tabs settings"),
 *   field_types = {
 *     "ebt_settings"
 *   }
 * )
 */
class EbtSettingsTabsWidget extends WidgetBase {

  /**
   * {@inheritdoc}
   */
  public function formElement(FieldItemListInterface $items, $delta, array $element, array &$form, FormStateInterface $form_state) {
    $element['ebt_settings'] = [
      '#type' => 'details',
      '#title' => 'Block settings',
      '#open' => FALSE,
    ];

    $element['ebt_settings']['styles'] = [
      '#title' => $this->t('Styles'),
      '#type' => 'radios',
      '#options' => [
        'default' => 'Default',
        'without_header_background' => 'Without header background',
        'minimalist_tabs' => 'Minimalist tabs',
        'tabs_like_buttons' => 'Tabs like buttons',
        'vertical_tabs' => 'Vertical tabs',
        'vertical_tabs_rotated' => 'Vertical tabs rotated',
      ],
      '#default_value' => isset($items[$delta]->ebt_settings['styles']) ? $items[$delta]->ebt_settings['styles'] : 'default',
      '#description' => $this->t('Select predefined styles for tabs.'),
    ];


    $element['ebt_settings']['active'] = [
      '#title' => $this->t('Active section'),
      '#type' => 'textfield',
      '#default_value' => isset($items[$delta]->ebt_settings['active']) ? $items[$delta]->ebt_settings['active'] : NULL,
      '#description' => $this->t('The zero-based index of the panel that is active (open). A negative value selects panels going backward from the last panel.'),
    ];

    $element['ebt_settings']['collapsible'] = [
      '#title' => $this->t('Collapsible'),
      '#type' => 'checkbox',
      '#default_value' => isset($items[$delta]->ebt_settings['collapsible']) ? $items[$delta]->ebt_settings['collapsible'] : NULL,
      '#description' => 'Whether all the sections can be closed at once. Allows collapsing the active section.',
    ];

    $element['ebt_settings']['closed'] = [
      '#title' => $this->t('All closed'),
      '#type' => 'checkbox',
      '#default_value' => isset($items[$delta]->ebt_settings['closed']) ? $items[$delta]->ebt_settings['closed'] : NULL,
      '#description' => 'Collapses all panels',
    ];

    $element['ebt_settings']['disable'] = [
      '#title' => $this->t('Disable'),
      '#type' => 'checkbox',
      '#default_value' => isset($items[$delta]->ebt_settings['disable']) ? $items[$delta]->ebt_settings['disable'] : NULL,
      '#description' => $this->t('Disables the tabs.'),
    ];

    $element['ebt_settings']['heightStyle'] = [
      '#title' => $this->t('Height style'),
      '#type' => 'radios',
      '#options' => [
        'auto' => 'Auto',
        'fill' => 'Fill',
        'content' => 'Content',
      ],
      '#default_value' => isset($items[$delta]->ebt_settings['heightStyle']) ? $items[$delta]->ebt_settings['heightStyle'] : 'content',
      '#description' => $this->t('Controls the height of the accordion and each panel.'),
    ];

    return $element;
  }

  /**
   * {@inheritdoc}
   */
  public function massageFormValues(array $values, array $form, FormStateInterface $form_state) {
    foreach ($values as &$value) {
      $value += ['ebt_settings' => []];
    }
    return $values;
  }

}
